-- This mod requires Mobs Redo.

-- ===================================================================

local modname = minetest.get_current_modname()
local modpath = minetest.get_modpath (modname)
local aoc     = tonumber (minetest.setting_get ("sealife_aoc")) or 8

-- ===================================================================

local sealife_disable_crocs          =
      minetest.setting_getbool ("sealife_disable_crocs"          )
local sealife_disable_mobs           =
      minetest.setting_getbool ("sealife_disable_mobs"           )
local sealife_disable_monsters       =
      minetest.setting_getbool ("sealife_disable_monsters"       )
local sealife_peaceful               =
      minetest.setting_getbool ("sealife_peaceful"               )

local monsttype = "monster"
if    sealife_peaceful then
      monsttype = "animal"
end

local mobname
local xyz

-- ===================================================================

local function getnumsetting (name)
    local  n = tonumber (minetest.setting_get (name)) or 0
    return n
end

-- ===================================================================

local chance    = 120000
    xyz = getnumsetting ("sealife_crocs_chance")
if  xyz ~= 0 then
      chance    = xyz
end

local minheight =    -10
    xyz = getnumsetting ("sealife_crocs_minheight")
if  xyz == 0 then
    xyz = getnumsetting ("sealife_minheight")
end
if  xyz ~= 0 then
      minheight = xyz
end

local maxheight =      1
    xyz = getnumsetting ("sealife_crocs_maxheight")
if  xyz == 0 then
    xyz = getnumsetting ("sealife_maxheight")
end
if  xyz ~= 0 then
      maxheight = xyz
end

-- ===================================================================

local l_skins = {
    { "croco.png"  } ,
    { "croco2.png" } ,
}

local l_anims = {
    speed_normal = 24,  speed_run = 24,
    stand_start = 0,    stand_end = 80,
    walk_start = 81,    walk_end = 170,
    run_start = 81,     run_end = 170,
    punch_start = 205,  punch_end = 220
}

local l_model           = "crocodile.x"
local l_sounds          = {random = "croco"}
local l_egg_texture     = "default_grass.png"

-- load settings
dofile (modpath .. "/settings.txt")

-- ===================================================================

if ENABLE_WALKERS then
mobname = modname .. ":croc"

mobs:register_mob (mobname,
{
    type = monsttype,
    attack_type = "dogfight",
    damage = 8,
    hp_min = 20,
    hp_max = 25,
    armor = 200,
    collisionbox = {-0.85, -0.30, -0.85, 0.85, 1.5, 0.85},
    drawtype = "front",
    visual = "mesh",
    mesh = l_model,
    textures = l_skins,
    visual_size = {x=4, y=4},
    sounds = l_sounds,
    fly = false,
    floats = 0,
    stepheight = 1,
    view_range = 10,
    water_damage = 0,
    lava_damage = 10,
    light_damage = 0,
    animation = l_anims
})

if not sealife_disable_crocs    and
   not sealife_disable_mobs     and
   not sealife_disable_monsters then
    mobs:spawn_specific (mobname,
{
    "default:dirt_with_grass" ,
    "default:dirt"            ,
    "default:jungle_grass"    ,
    "default:sand"            ,
} ,
{
    "default:water_flowing"   ,
    "default:water_source"    ,
    "default:papyrus"         ,
    "dryplants:juncus"        ,
    "dryplants:reedmace"      ,
} ,
5, 18, 30, chance, aoc, minheight, maxheight)
end
    mobs:register_egg (mobname, "Crocodile", l_egg_texture, 1)
end

-- ===================================================================

if ENABLE_FLOATERS then
mobname = modname .. ":croc_float"

mobs:register_mob (mobname, {
    type = monsttype,
    attack_type = "dogfight",
    damage = 8,
    hp_min = 20,
    hp_max = 25,
    armor = 200,
    collisionbox = {-0.638, -0.23, -0.638, 0.638, 1.13, 0.638},
    drawtype = "front",
    visual = "mesh",
    mesh = l_model,
    textures = l_skins,
    visual_size = {x=3, y=3},
    sounds = l_sounds,
    fly = false,
    stepheight = 1,
    view_range = 10,
    water_damage = 0,
    lava_damage = 10,
    light_damage = 0,
    animation = l_anims
})

if not sealife_disable_crocs    and
   not sealife_disable_mobs     and
   not sealife_disable_monsters then
    mobs:spawn_specific (mobname,
{
    "default:water_flowing"   ,
    "default:water_source"    ,
} ,
{
    "default:dirt"            ,
    "default:dirt_with_grass" ,
    "default:jungle_grass"    ,
    "default:sand"            ,
    "default:papyrus"         ,
    "dryplants:juncus"        ,
    "dryplants:reedmace"      ,
    "group:seaplants"         ,
} ,
5, 18, 30, chance, aoc, minheight, maxheight)
end
    mobs:register_egg (mobname,
"Crocodile (floater)", l_egg_texture, 1)
end

-- ===================================================================

if ENABLE_SWIMMERS then
mobname = modname .. ":croc_swim"

mobs:register_mob (mobname, {
    type = monsttype,
    attack_type = "dogfight",
    damage = 8,
    hp_min = 20,
    hp_max = 25,
    armor = 200,
    collisionbox = {-0.425, -0.15, -0.425, 0.425, 0.75, 0.425},
    drawtype = "front",
    visual = "mesh",
    mesh = l_model,
    textures = l_skins,
    visual_size = {x=2, y=2},
    sounds = l_sounds,
    fly = true,
    fly_in = "default:water_source",
    fall_speed = -1,
    floats = 0,
    view_range = 10,
    water_damage = 0,
    lava_damage = 10,
    light_damage = 0,
    animation = l_anims
})

if not sealife_disable_crocs    and
   not sealife_disable_mobs     and
   not sealife_disable_monsters then
    mobs:spawn_specific (mobname,
{
    "default:water_flowing" ,
    "default:water_source"  ,
} ,
{
    "default:sand"          ,
    "default:dirt"          ,
    "group:seaplants"       ,
} ,
5, 18, 30, chance, aoc, minheight, maxheight)
end
    mobs:register_egg (mobname,
"Crocodile (swimmer)", l_egg_texture, 1)
end
