-- This mod requires Mobs Redo.

-- ===================================================================

local modname = minetest.get_current_modname()
local modpath = minetest.get_modpath (modname)
local aoc     = tonumber (minetest.setting_get ("sealife_aoc")) or 8

-- ===================================================================

local sealife_disable_fish           =
      minetest.setting_getbool ("sealife_disable_fish"           )
local sealife_disable_mobs           =
      minetest.setting_getbool ("sealife_disable_mobs"           )
local sealife_disable_monsters       =
      minetest.setting_getbool ("sealife_disable_monsters"       )
local sealife_peaceful               =
      minetest.setting_getbool ("sealife_peaceful"               )

local monsttype = "animal"
if    sealife_peaceful then
      monsttype = "animal"
end

local mobname
local xyz

-- ===================================================================

local function getnumsetting (name)
    local  n = tonumber (minetest.setting_get (name)) or 0
    return n
end

-- ===================================================================

local chance    =    400
    xyz = getnumsetting ("sealife_fish_chance")
if  xyz ~= 0 then
    chance      = xyz
end

local minheight = -31000
    xyz = getnumsetting ("sealife_fish_minheight")
if  xyz == 0 then
    xyz = getnumsetting ("sealife_minheight")
end
if  xyz ~= 0 then
      minheight = xyz
end

local maxheight =     -1
    xyz = getnumsetting ("sealife_fish_maxheight")
if  xyz == 0 then
    xyz = getnumsetting ("sealife_maxheight")
end
if  xyz ~= 0 then
      maxheight = xyz
end

-- ===================================================================

-- set to true to use upright sprites instead of meshes
local SPRITE_VERSION = false

local l_spawn_in     = {
    "default:water_source"        ,
    "default:water_flowing"       ,
    "default:river_water_source"  ,
    "default:river_water_flowing" ,
}

local l_spawn_near   = {
    "darkage:silt"           ,
    "default:sand"           ,
    "default:dirt"           ,
    "ethereal:dry_dirt"      ,
    "ethereal:green_dirt"    ,
    "ethereal:grove_dirt"    ,
    "ethereal:mushroom_dirt" ,
    "group:seaplants"        ,
    "group:seacoral"         ,
}

local l_cc_hand      = 25
local l_cc_net       = 80
local l_water_level  = minetest.setting_get ("water_level") - 1

local l_anims = {
    speed_normal = 24,      speed_run = 24,
    stand_start = 1,        stand_end = 80,
    walk_start = 81,        walk_end = 155,
    run_start = 81,         run_end = 155
}

local l_visual = "mesh"
local l_visual_size = {x=.75, y=.75}
local l_clown_mesh = "animal_clownfish.b3d"
local l_trop_mesh = "fish_blue_white.b3d"

local l_clown_textures = {
    {"clownfish.png"},
    {"clownfish2.png"}
}

local l_trop_textures = {
    {"fish.png"},
    {"fish2.png"},
    {"fish3.png"}
}

if SPRITE_VERSION then
    l_visual = "upright_sprite"
    l_visual_size = {x=.5, y=.5}
    l_clown_mesh = nil
    l_trop_mesh = nil
    l_clown_textures = {{"animal_clownfish_clownfish_item.png"}}
    l_trop_textures = {{"bwfishitem.png"}}
end

-- ===================================================================

mobname = modname .. ":clownfish"

mobs:register_mob (mobname, {
    type = "animal",
    passive = true,
    hp_min = 1,
    hp_max = 4,
    armor = 100,
    collisionbox = {-0.25, -0.25, -0.25, 0.25, 0.25, 0.25},
    rotate = 270,
    visual = l_visual,
    mesh = l_clown_mesh,
    textures = l_clown_textures,
    visual_size = l_visual_size,
    makes_footstep_sound = false,
    stepheight = 0.1,
    fly = true,
    fly_in = "default:water_source",
    fall_speed = 0,
    view_range = 8,
    water_damage = 0,
    lava_damage = 5,
    light_damage = 0,
    animation = l_anims,

    on_rightclick = function (self, clicker)
        mobs:capture_mob (self, clicker, l_cc_hand, l_cc_net, 0, true, nil)
    end
})

if not sealife_disable_fish and
   not sealife_disable_mobs then
    mobs:spawn_specific (mobname,
l_spawn_in, l_spawn_near, 2, 20, 30,
chance, aoc, minheight, maxheight)
end

mobs:register_egg (mobname,
"Clownfish", "animal_clownfish_clownfish_item.png", 0)

-- ===================================================================

mobname = modname .. ":tropical"

mobs:register_mob (mobname, {
    type = "animal",
    passive = true,
    hp_min = 1,
    hp_max = 4,
    armor = 100,
    collisionbox = {-0.25, -0.25, -0.25, 0.25, 0.25, 0.25},
    rotate = 270,
    visual = l_visual,
    mesh = l_trop_mesh,
    textures = l_trop_textures,
    visual_size = l_visual_size,
    makes_footstep_sound = false,
    stepheight = 0.1,
    fly = true,
    fly_in = "default:water_source",
    fall_speed = 0,
    view_range = 8,
    water_damage = 0,
    lava_damage = 5,
    light_damage = 0,
    animation = l_anims,

    on_rightclick = function (self, clicker)
        mobs:capture_mob (self, clicker, l_cc_hand, l_cc_net, 0, true, nil)
    end
})

if not sealife_disable_fish and
   not sealife_disable_mobs then
    mobs:spawn_specific (mobname,
l_spawn_in, l_spawn_near, 1, 20, 30,
chance, aoc, minheight, maxheight)
end

mobs:register_egg (mobname,
"Tropical fish", "bwfishitem.png", 0)
