-- This mod requires Mobs Redo.

-- ===================================================================

local modname = minetest.get_current_modname()
local modpath = minetest.get_modpath (modname)
local aoc     = tonumber (minetest.setting_get ("sealife_aoc")) or 8

-- ===================================================================

local sealife_disable_sharks         =
      minetest.setting_getbool ("sealife_disable_sharks"         )
local sealife_disable_mobs           =
      minetest.setting_getbool ("sealife_disable_mobs"           )
local sealife_disable_monsters       =
      minetest.setting_getbool ("sealife_disable_monsters"       )
local sealife_peaceful               =
      minetest.setting_getbool ("sealife_peaceful"               )

local monsttype = "monster"
if    sealife_peaceful then
      monsttype = "animal"
end

local mobname
local xyz

-- ===================================================================

local function getnumsetting (name)
    local  n = tonumber (minetest.setting_get (name)) or 0
    return n
end

-- ===================================================================

local chance    =  90000
    xyz = getnumsetting ("sealife_sharks_chance")
if  xyz ~= 0 then
      chance    = xyz
end

local minheight = -31000
    xyz = getnumsetting ("sealife_sharks_minheight")
if  xyz == 0 then
    xyz = getnumsetting ("sealife_minheight")
end
if  xyz ~= 0 then
      minheight = xyz
end

local maxheight =     -1
    xyz = getnumsetting ("sealife_sharks_maxheight")
if  xyz == 0 then
    xyz = getnumsetting ("sealife_maxheight")
end
if  xyz ~= 0 then
      maxheight = xyz
end

-- ===================================================================

local l_colors = {
    "#604000:175",  --brown
    "#ffffff:150",  --white
    "#404040:150",  --dark_grey
    "#a0a0a0:150"   --grey
}

local l_skins = {
    {"(shark_first.png^[colorize:"..l_colors[3]..")^(shark_second.png^[colorize:"..l_colors[4]..")^shark_third.png"},
    {"(shark_first.png^[colorize:"..l_colors[1]..")^(shark_second.png^[colorize:"..l_colors[2]..")^shark_third.png"},
    {"(shark_first.png^[colorize:"..l_colors[4]..")^(shark_second.png^[colorize:"..l_colors[2]..")^shark_third.png"}
}

local l_anims = {
    speed_normal = 24,  speed_run = 24,
    stand_start = 1,    stand_end = 80,
    walk_start = 80,    walk_end = 160,
    run_start = 80,     run_end = 160
}

local l_model           = "mob_shark.b3d"
local l_egg_texture     = "mob_shark_shark_item.png"

local l_spawn_in     = { "default:water_flowing", "default:water_source", "default:river_water_flowing", "default:river_water_source" }
local l_spawn_near   = { "default:water_flowing", "default:water_source", "default:river_water_flowing", "default:river_water_source", "seawrecks:woodship", "seawrecks:uboot" }

-- load settings
dofile (modpath .. "/settings.txt")

-- ===================================================================

if ENABLE_SHARK_LARGE then
mobname = modname .. ":shark_large"

mobs:register_mob (mobname, {
    type = "monster",
    attack_type = "dogfight",
    damage = 10,
    hp_min = 20,
    hp_max = 25,
    armor = 150,
    collisionbox = {-0.75, -0.5, -0.75, 0.75, 0.5, 0.75},
    visual = "mesh",
    mesh = l_model,
    textures = l_skins,
    makes_footstep_sound = false,
    walk_velocity = 4,
    run_velocity = 6,
    fly = true,
    fly_in = "default:water_source",
    fall_speed = 0,
    rotate = 270,
    view_range = 10,
    water_damage = 0,
    lava_damage = 10,
    light_damage = 0,
    animation = l_anims,

    do_custom = function(self)
        if HELP_WITH_EXPERIMENT then
            local p = self.object:getpos()
            local a = self.object:getvelocity()
            if p.y > 0 and a.y > 0 then
                a.y = -1
            else
                local r = math.random(100)
                if r >= 1 and r <=25 then a.y = 0.25
                elseif r > 25 and r <= 50 then a.y = 0
                elseif r > 50 and r <= 75 then a.y = -0.25
                end
            end
            self.object:setvelocity(a)
        end
    end
})

if not sealife_disable_sharks   and
   not sealife_disable_mobs     and
   not sealife_disable_monsters then
    mobs:spawn_specific (mobname,
l_spawn_in, l_spawn_near, -1, 20, 30,
chance, aoc, minheight, maxheight)
end
    mobs:register_egg (mobname,
"Shark (large)", l_egg_texture, 0)
end

-- ===================================================================

if ENABLE_SHARK_MEDIUM then
mobname = modname .. ":shark_medium"

mobs:register_mob (mobname, {
    type = "monster",
    attack_type = "dogfight",
    damage = 8,
    hp_min = 15,
    hp_max = 20,
    armor = 125,
    collisionbox = {-0.57, -0.38, -0.57, 0.57, 0.38, 0.57},
    visual = "mesh",
    visual_size = {x=0.75, y=0.75},
    mesh = l_model,
    textures = l_skins,
    makes_footstep_sound = false,
    walk_velocity = 2,
    run_velocity = 4,
    fly = true,
    fly_in = "default:water_source",
    fall_speed = -1,
    rotate = 270,
    view_range = 10,
    water_damage = 0,
    lava_damage = 10,
    light_damage = 0,
    animation = l_anims
})

if not sealife_disable_sharks   and
   not sealife_disable_mobs     and
   not sealife_disable_monsters then
    mobs:spawn_specific (mobname,
l_spawn_in, l_spawn_near, -1, 20, 30,
chance, aoc, minheight, maxheight)
end
    mobs:register_egg (mobname, "Shark (medium)", l_egg_texture, 0)
end

-- ===================================================================

if ENABLE_SHARK_SMALL then
mobname = modname .. ":shark_small"

mobs:register_mob (mobname, {
    type = "monster",
    attack_type = "dogfight",
    damage = 6,
    hp_min = 10,
    hp_max = 15,
    armor = 100,
    collisionbox = {-0.38, -0.25, -0.38, 0.38, 0.25, 0.38},
    visual = "mesh",
    visual_size = {x=0.5, y=0.5},
    mesh = l_model,
    textures = l_skins,
    makes_footstep_sound = false,
    walk_velocity = 2,
    run_velocity = 4,
    fly = true,
    fly_in = "default:water_source",
    fall_speed = -1,
    rotate = 270,
    view_range = 10,
    water_damage = 0,
    lava_damage = 10,
    light_damage = 0,
    animation = l_anims
})

if not sealife_disable_sharks   and
   not sealife_disable_mobs     and
   not sealife_disable_monsters then
    mobs:spawn_specific (mobname,
l_spawn_in, l_spawn_near, -1, 20, 30,
chance, aoc, minheight, maxheight)
end
    mobs:register_egg (mobname, "Shark (small)", l_egg_texture, 0)
end
